#
# spec file for package ghc-resourcet
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name resourcet
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.3.0
Release:        150500.3.3.3
Summary:        Deterministic allocation and freeing of scarce resources
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-primitive-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unliftio-core-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-hspec-devel
%endif

%description
Hackage documentation generation is not reliable. For up to date documentation,
please see: <http://www.stackage.org/package/resourcet>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%changelog
* Sun Oct 23 2022 psimons@suse.com
- Update resourcet to version 1.3.0.
  [#]# 1.3.0
  * Include the exception in ReleaseTypes indicating exceptional exit.
    Only backwards-incompatible in code relying on instances of ReleaseType
    other than Show, or constructing ReleaseException directly.
* Thu Jun 30 2022 psimons@suse.com
- Update resourcet to version 1.2.6.
  [#]# 1.2.6
  * Add `allocateU` [#490](https://github.com/snoyberg/conduit/pull/490)
* Tue May 10 2022 psimons@suse.com
- Update resourcet to version 1.2.5.
  [#]# 1.2.5
  * Support `transformers-0.6` / `mtl-2.3`
* Fri Feb  4 2022 psimons@suse.com
- Update resourcet to version 1.2.4.3 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Aug  5 2021 psimons@suse.com
- Update resourcet to version 1.2.4.3.
  [#]# 1.2.4.3
  * Fix a space leak when using `forever` with `ResourceT`. [#470](https://github.com/snoyberg/conduit/pull/470)
* Thu Dec 17 2020 mimi.vx@gmail.com
- disable %%{ix86} build
* Tue Aug 18 2020 psimons@suse.com
- Replace %%setup -q with the more modern %%autosetup macro.
* Fri Jun 26 2020 psimons@suse.com
- Update resourcet to version 1.2.4.2.
  [#]# 1.2.4.2
  * Mask exceptions in `Acquire` allocation action
* Tue Jun  9 2020 psimons@suse.com
- Update resourcet to version 1.2.4.1.
  [#]# 1.2.4.1
  * Document risk of using `forkIO` within a `ResourceT` [#441](https://github.com/snoyberg/conduit/pull/441)
  [#]# 1.2.4
  * Add `allocate_` [#437](https://github.com/snoyberg/conduit/pull/437)
* Wed May  6 2020 psimons@suse.com
- Update resourcet to version 1.2.4.
  [#] ChangeLog for resourcet
  [#]# 1.2.3
  * Support `unliftio-core` 0.2.0.0
* Fri Nov  8 2019 psimons@suse.com
- Drop obsolete group attributes.
* Wed Oct 10 2018 psimons@suse.com
- Update resourcet to version 1.2.2.
  [#]# 1.2.2
  * Add `MonadFail` instance for `ResourceT`.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update resourcet to version 1.2.1.
  * Support `exceptions-0.10`.
  * Drop `monad-control` and `mmorph` dependencies
  * Change behavior of `runResourceT` to match `runResourceTChecked`
  * `runResourceTChecked`, which checks if any of the cleanup actions
    threw exceptions and, if so, rethrows them. __NOTE__ This is
    probably a much better choice of function than `runResourceT`, and
    in the next major version release, will become the new behavior of
    `runResourceT`.
  * Added `MonadUnliftIO` instances and `UnliftIO.Resource`
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Mon Jan  9 2017 psimons@suse.com
- Update to version 1.1.9 with cabal2obs.
* Mon Nov 14 2016 psimons@suse.com
- Update to version 1.1.8.1 with cabal2obs.
* Mon Oct 17 2016 psimons@suse.com
- Update to version 1.1.8 with cabal2obs.
* Wed Aug 17 2016 psimons@suse.com
- Update to version 1.1.7.5 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.1.7.4 revision 0 with cabal2obs.
* Sat May  7 2016 mimi.vx@gmail.com
- update to 1.1.7.4
  * Make test suite slightly more robust
* Tue Mar  8 2016 mimi.vx@gmail.com
- update to 1.1.7.3
* Mon Feb 22 2016 mimi.vx@gmail.com
- update to 1.1.7.2
  * Remove upper bound on transformers
* Wed Jan 27 2016 mimi.vx@gmail.com
- update to 1.1.7.1
  * transformers-compat 0.5
* Mon Dec  7 2015 mimi.vx@gmail.com
- update to 1.1.7
  * Canonicalise Monad instances
* Tue Aug  4 2015 mimi.vx@gmail.com
- update to 1.1.6
  * Safe/Trustworthy for resourcet
* Tue May 26 2015 mimi.vx@gmail.com
- update to 1.1.5
  * Add pass-through instances for Alternative and MonadPlus
* Tue Apr 21 2015 mimi.vx@gmail.com
- update to 1.1.4.1
  * Add `MonadResource ExceptT` instance
* Sun Feb  1 2015 mpluskal@suse.com
- Add dependency on ghc-exceptions which is now required
- Update to 1.1.3.3:
  + monad-control-1.0 support
  + Provide the `withEx` function to interact nicely with the
    exceptions package.
* Sun Oct  6 2013 sbahling@suse.com
- Initial package - version 0.4.8
